@@ -5,6 +5,9 @@ package SFDC;
 use strict;
 use warnings;
 use 5.10.0;
+
+our $VERSION = '0.06'; # TRIAL VERSION
+
 use App::SFDC;
 
 
@@ -26,16 +29,16 @@ sub usage {"
 # GetOptions, which is why we shift instead of using $_[0]
 
 local $_ = shift;
-if (/retrieve/i) {
-    App::SFDC::Retrieve->new_with_options->execute();
-} elsif (/deploy/i) {
-    App::SFDC::Deploy->new_with_options->execute();
-} else {
-    print usage;
+exit not do {
+    if (/retrieve/i) {
+        App::SFDC::Retrieve->new_with_options->execute();
+    } elsif (/deploy/i) {
+        App::SFDC::Deploy->new_with_options->execute();
+    } else {
+        print usage;
+    }
 }
 
-1;
-
 __END__
 
 =pod
@@ -46,7 +49,7 @@ SFDC - Command tool for interacting with Salesforce.com
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 DESCRIPTION
 
